@@ -99,7 +99,8 @@ class Telescope():
                 "acu.feed_indexer.p_set", 
                 "acu.feed_indexer.p_act", 
                 "acu.feed_indexer.state",
-                "acu.tracking.tracking_status.tr_valid"]
+                "acu.tracking.tracking_status.tr_valid",
+                'datalogging.currentstate']
 
     def __init__(self, speedup_factor=1, t_start = astropy.time.Time.now(), use_realtime=True, UPDATE_INTERVAL = .2, do_write_history = False):
         self.stop = False
@@ -259,7 +260,9 @@ class Telescope():
             tunix = [tt.unix for tt in times]
 
             df = pd.DataFrame(values, index=tunix, columns = Telescope.datalog_cols)
-        
+
+        df = df.loc[~df.index.duplicated(),~df.columns.duplicated()].copy()
+
         if interval_ms is not None:
             dt = interval_ms / 1000
 
@@ -355,6 +358,9 @@ class Telescope():
         _log.debug("action dummy")
         _log.warning("Dummy action called:\n%s", json.dumps(body, indent=4))
 
+    def stop_loading_track(self):
+        return dict(status=200, headers={}, body="{}")
+
     def program_track(self, body):
         _log.debug("program track")
         with self.dataLock:
